@@ -1,7 +1,7 @@
 # Re-export.
 # flake8: noqa
 
-from .immutable import ImmutableBase, Immutable, update
+from .immutable import ImmutableBase, Immutable, create, update
 from .immutable import ImmutableList, ImmutableSet, ImmutableDict
 from .revisioned import RevisionedImmutableBase, RevisionedImmutable
 from .revisioned import SimpleRevisionedImmutableManager, RevisionedMapping
