@@ -6,6 +6,7 @@
 """Immutable Interfaces."""
 import datetime
 import decimal
+from enum import Enum
 
 import zope.interface
 import zope.lifecycleevent
@@ -24,11 +25,13 @@ IM_STATE_RETIRED = 'retired'
 IM_STATE_DELETED = 'deleted'
 IM_STATES_REVISIONED = (
     IM_STATE_LOCKED, IM_STATE_TRANSIENT, IM_STATE_RETIRED, IM_STATE_DELETED)
+IM_STATES_OUTDATED = (IM_STATE_DELETED, IM_STATE_RETIRED)
 
 IMMUTABLE_TYPES = (
     bool, int, float, complex, decimal.Decimal, tuple, str, bytes, type(None),
     datetime.date, datetime.time, datetime.datetime, datetime.timedelta,
     datetime.tzinfo,
+    Enum
 )
 
 LIST_TYPES = (
@@ -409,7 +412,7 @@ class IRevisionedImmutable(IImmutable):
         If the immutable is already in the `transient` state, then the object
         itself is returned. All arguments to the method are ignored.
 
-        If a clone is created, then the `__im_creator__` and `__im_commnet__`
+        If a clone is created, then the `__im_creator__` and `__im_comment__`
         attributes will be set.
 
         If `__im_manager__` is set,
