@@ -9,6 +9,7 @@ import datetime
 import mock
 import pjpersist.interfaces as pjinterfaces
 import pjpersist.sqlbuilder as sb
+import psycopg2
 import transaction
 import unittest
 import zope.component
@@ -186,9 +187,11 @@ class ImmutableTest(unittest.TestCase):
 class ImmutableContainerTest(unittest.TestCase):
 
     def setUp(self):
-        self.conn = mock.MagicMock(
-            dsn='postgresql://localhost/db')
-        self.dm = datamanager.PJDataManager(self.conn)
+        conn = mock.MagicMock(
+            dsn='postgresql://localhost/db',
+            status=psycopg2.extensions.STATUS_READY)
+        pool = testing.DummyConnectionPool(conn)
+        self.dm = datamanager.PJDataManager(pool)
         self.cont = pjpersist.ImmutableContainer()
         self.cont._p_jar = self.dm
         self.cont._pj_table = 'table'
@@ -721,3 +724,18 @@ class ImmutableDatabaseTest(testing.PJTestCase):
         # And it is available in the regualr container as well.
         self.assertEqual(len(questions), 1)
         self.assertIn(qname, questions)
+
+    def test_no_double_update(self):
+        with Question.__im_create__() as factory:
+            q = factory('What is the answer')
+        self.questions.add(q)
+
+        with q.__im_update__() as q2:
+            q2.answer = 42
+
+        # second call to __im_update__ of the original object
+        with self.assertRaises(AssertionError):
+            with q.__im_update__() as q3:
+                q3.answer = 43
+
+        transaction.commit()
